use_qmd.RdUse the DCR quarto html template This function will download and optionally open the quarto markdown (qmd) file and the other necessary files from github.
Use the DCR quarto revealjs presentation template This function will download and optionally open the quarto markdown (qmd) file and the other necessary files from github.
Use the DCR quarto html recruitment report template This function will download and optionally open the quarto markdown (qmd) file and the other necessary files from github.
Use the DCR quarto html sample size report template This function will download and optionally open the quarto markdown (qmd) file and the other necessary files from github.
Use the DCR quarto typst template This function will download and optionally open the quarto markdown (qmd) file and the other necessary files from github.
use_qmd_html(save_in = ".", open = TRUE, ping = TRUE)
use_qmd_pres(save_in = ".", open = TRUE, ping = TRUE)
use_qmd_htmlrecruitment(save_in = ".", open = TRUE, ping = TRUE)
use_qmd_htmlsampsi(save_in = ".", open = TRUE, ping = TRUE)
use_qmd_typst(save_in = ".", open = TRUE, ping = TRUE)use_qmd_pres(): revealjs Presentation Template
use_qmd_htmlrecruitment(): Recruitment Report Template
use_qmd_htmlsampsi(): Sample Size Report Template
use_qmd_typst(): Sample Size Report Template
# dir <- tempdir()
# file <- file.path(dir, "filename.qmd")
# use_qmd_html(file, FALSE)
# in practice at CTU:
# use_qmd_html("08_Reports_xx/ReportName.qmd", TRUE)
# dir <- tempdir()
# file <- file.path(dir, "filename.qmd")
# use_qmd_pres(file, FALSE)
# in practice at CTU:
# use_qmd_pres("08_Reports_xx/ReportName.qmd", TRUE)
# dir <- tempdir()
# file <- file.path(dir, "filename.qmd")
# use_qmd_html(file, FALSE)
# in practice at CTU:
# use_qmd_htmlrecruitment("08_Reports_xx/ReportName.qmd", TRUE)
# dir <- tempdir()
# file <- file.path(dir, "filename.qmd")
# use_qmd_html(file, FALSE)
# in practice at CTU:
# use_qmd_htmlrecruitment("08_Reports_xx/ReportName.qmd", TRUE)
# dir <- tempdir()
# file <- file.path(dir, "filename.qmd")
# use_qmd_html(file, FALSE)
# in practice at CTU:
# use_qmd_typst("08_Reports_xx/ReportName.qmd", TRUE)